import numpy as np
from sklearn.model_selection import train_test_split
from sklearn.neighbors import KNeighborsClassifier
import matplotlib.pyplot as plt
from matplotlib.colors import ListedColormap


D = np.loadtxt( "datos.txt" )
print( D.shape )

X = D[:,0:2]
y = D[:,2]

# Separamos los datos en datos de entrenamiento y datos de prueba
X_entrena, X_prueba, y_entrena, y_prueba = train_test_split( X, y, random_state=4 )

clasificador = KNeighborsClassifier( n_neighbors=9 )
clasificador.fit( X_entrena, y_entrena )

# Calcula la exactitud del clasificador
v = clasificador.score( X_prueba, y_prueba )
print( v )

# Hacemos la gráfica de la superficie de decisión
# En x,y \in [-2,2]
n = 100
vx = np.linspace( -2, 3, n )
vy = np.linspace( -2, 2, n )

x, y = np.meshgrid( vx, vy )
Z = np.zeros( (n,n) )

va = np.zeros( (1,2) )

for i in range(n):
	for j in range(n):
		va[0,0]  = x[j,i]
		va[0,1]  = y[j,i]
		Z[j,i] = clasificador.predict( va )


fig, ax = plt.subplots()

cm = plt.cm.RdBu
cm_bright = ListedColormap(['#FF0000', '#0000FF'])

ax.contourf( x, y, Z, cmap=cm, alpha=.8 )
ax.set_aspect(1)
# ax.scatter( decision.Vs[:,0], decision.Vs[:,1] )
ax.set_xticks(())
ax.set_yticks(())
ax.scatter( X_entrena[:,0], X_entrena[:,1], c=y_entrena, cmap=cm_bright, edgecolors='k' )
ax.scatter( X_prueba[:,0], X_prueba[:,1], marker='x', c=y_prueba, cmap=cm_bright, edgecolors='k' )

plt.show( )

